@@ -7,33 +7,14 @@ use warnings;
 use utf8;
 
 use English qw(-no_match_vars);
-use Const::Fast;
+use Module::Find;
 use namespace::autoclean;
 
-our $VERSION = '0.001';    # VERSION
+our $VERSION = '0.002';    # VERSION
 
 # ABSTRACT: Inline display of plotly charts in Jupyter notebooks using L<Devel::IPerl> kernel
 
-sub register {
-
-    # only works registering the plugin for each notebook
-    require Chart::Plotly::Plot;
-    require Role::Tiny;
-
-    Role::Tiny->apply_roles_to_package( 'Chart::Plotly::Plot',
-                                        q(Devel::IPerl::Plugin::Chart::Plotly::Plot::IPerlRole) );
-}
-
-{
-    package Devel::IPerl::Plugin::Chart::Plotly::Plot::IPerlRole;
-
-    use Moo::Role;
-
-    use Devel::IPerl::Display::HTML;
-
-    sub iperl_data_representations {
-        my ($plot) = @_;
-        my $require_plotly = '
+my $require_plotly = '
 <script>
             if(!window.Plotly) {
                 requirejs.config({
@@ -51,6 +32,45 @@ sub register {
             }
 </script>
 ';
+
+sub register {
+
+    # only works registering the plugin for each notebook
+    require Chart::Plotly::Plot;
+    require Role::Tiny;
+
+    Role::Tiny->apply_roles_to_package( 'Chart::Plotly::Plot',
+                                        q(Devel::IPerl::Plugin::Chart::Plotly::Plot::IPerlRole) );
+    for my $module ( findsubmod('Chart::Plotly::Trace') ) {
+        Role::Tiny->apply_roles_to_package( $module, q(Devel::IPerl::Plugin::Chart::Plotly::Plot::Trace::IPerlRole) );
+    }
+}
+
+{
+    package Devel::IPerl::Plugin::Chart::Plotly::Plot::IPerlRole;
+
+    use Moo::Role;
+
+    use Devel::IPerl::Display::HTML;
+
+    sub iperl_data_representations {
+        my ($plot) = @_;
+        Devel::IPerl::Display::HTML->new( $require_plotly . $plot->html )->iperl_data_representations;
+    }
+
+}
+
+{
+    package Devel::IPerl::Plugin::Chart::Plotly::Plot::Trace::IPerlRole;
+
+    use Moo::Role;
+
+    use Devel::IPerl::Display::HTML;
+
+    sub iperl_data_representations {
+        require Chart::Plotly::Plot;
+        my ($trace) = @_;
+        my $plot = Chart::Plotly::Plot->new( traces => [$trace] );
         Devel::IPerl::Display::HTML->new( $require_plotly . $plot->html )->iperl_data_representations;
     }
 
@@ -70,17 +90,25 @@ Devel::IPerl::Plugin::Chart::Plotly - Inline display of plotly charts in Jupyter
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
     # In notebook
     IPerl->load_plugin('Chart::Plotly');
 
+    # Trace objects get displayed automatically
     use Chart::Plotly::Trace::Scatter;
-    use Chart::Plotly::Plot;
     my $scatter_trace = Chart::Plotly::Trace::Scatter->new( x => [ 1 .. 5 ], y => [ 1 .. 5 ] );
-    my $plot = Chart::Plotly::Plot->new(traces => [$scatter_trace]);
+
+    # Also Plot objects
+    use Chart::Plotly::Trace::Box;
+    use Chart::Plotly::Plot;
+
+    my $x = [ 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3 ];
+    my $box1 = Chart::Plotly::Trace::Box->new( x => $x, y => [ map { rand() } ( 1 .. ( scalar(@$x) ) ) ], name => "box1" );
+    my $box2 = Chart::Plotly::Trace::Box->new( x => $x, y => [ map { rand() } ( 1 .. ( scalar(@$x) ) ) ], name => "box2" );
+    my $plot = Chart::Plotly::Plot->new( traces => [ $box1, $box2 ], layout => { boxmode => 'group' } );
 
 =head1 DESCRIPTION
 
